@@ -14,7 +14,7 @@ def main(path, name):
     click.secho(f"\n    Create path '{path}'", fg="yellow")
     install_path.mkdir(parents=True, exist_ok=True)
     click.secho(f"\n    Copy templates files from {pkg_templates_path} to {install_path}", fg="yellow")
-    pkg_name_dest = install_path.joinpath(name.lower())
+    pkg_name_dest = install_path.joinpath(name)
     if pkg_name_dest.exists():
         shutil.rmtree(pkg_name_dest)
     shutil.copytree(pkg_templates_path, install_path, dirs_exist_ok=True, copy_function=shutil.copy2)
